/************************************************
	Applied Biometric Systems GmbH (C) 2004
     		     EFIS.H 
************************************************/

#ifndef __EFISC_H
#define __EFISC_H

#define WIN32_LEAN_AND_MEAN

#include <stdlib.h>
#include <windows.h>
#include <winsock2.h>


//if defined(BUILD_DLL)
//  define DLL_EXP extern "C" _export __stdcall
//else
// if defined(BUILD_APP)
//  define DLL_EXP __declspec(dllimport)
// else
//  define DLL_EXP
//endif
//endif


#ifdef EFISC_EXPORTS
	#define EFISC __declspec( dllexport )
#else
	#ifdef EFISC_IMPORTS
		#define EFISC  __declspec( dllimport )
	#else
		#define EFISC
	#endif
#endif

typedef	unsigned char byte;


typedef struct {
	unsigned char	ID;
	unsigned char	fname[15];
	unsigned char	lname[15];
}	UserData;

typedef struct {
	unsigned char	ID;
	unsigned char	flag;
	unsigned char	temp[2048];
}	TempData;


#define	MAX_USERS	90


#define	EFIS321_VERSION_4		1


#define	TYPESCANNER_EFIS120		120
#define	TYPESCANNER_EFIS121		121
#define	TYPESCANNER_EFIS122		122
#define	TYPESCANNER_EFIS220		220
#define	TYPESCANNER_EFIS320		320
#define	TYPESCANNER_EFIS321		321

#define	TYPESCANNER_IFIS130		130
#define	TYPESCANNER_IFIS131		131

#define	TYPEDEVICE_EREL01		1000


#define H_EFIS120	440
#define W_EFIS120	280

#define H_EFIS220	384
#define W_EFIS220	256

#define H_EFIS320	300
#define W_EFIS320	256

#define H_IFIS130	440
#define W_IFIS130	280


#define ISNOTPRESENT				0

                                        
#define	rcOK						0
#define	rcErr					   -1
#define	rcFINGER_NOT_PRESENT		1
	
#define ERROR_DEVICE_NOTPRESENT		-3
#define	ERROR_TIMEOUT_RECV			-20
#define	ERROR_MEMORY_ALLOC			-21

#define	ERROR_NOTREAD_CONFIG		-30


#define	LED1_YELLOW_ON	0x02
#define	LED1_GREEN_ON	0x20
#define	LED1_RED_ON		0x10

#define	LED1_YELLOW_OFF	0xFD
#define	LED1_GREEN_OFF	0xDF
#define	LED1_RED_OFF	0xEF


/* only for EFIS321 */
#define	LED1_GREEN_TIMER	0x50
#define	LED1_RED_TIMER		0x51
#define	LED1_RELAY_TIMER	0x52


/* for efisFlashOn and efisFlashOff */
#define	YELLOW_FLASH	1
#define	GREEN_FLASH		2
#define	RED_FLASH		3


#define	S_RELAY_1	0x01
#define	S_RELAY_2	0x02
#define	S_RELAY_3	0x04
#define	S_RELAY_4	0x08
#define	S_RELAY_5	0x10
#define	S_RELAY_6	0x20
#define	S_RELAY_7	0x40
#define	S_RELAY_8	0x80



#if defined (__cplusplus)
extern "C" {
#endif

int		EFISC	efisOpenDevice(int typescanner, unsigned char * addr, int port);
int		EFISC	efisCloseDevice(int handle);

void	EFISC	efisSetOpenTimeout(int timeout);
void	EFISC	efisSetDetectLevel(int level);

int		EFISC	efisOpenDeviceBySocket(int typescanner, SOCKET ClientSock);
int		EFISC	efisOpenDeviceBySocketI(SOCKET ClientSock);
int		EFISC	efisCloseSocketByDevice(int handle);
int		EFISC	efisCloseSocketByDeviceA(int handle);

int		EFISC	efisStartActive(int typescanner, unsigned char * addr, int port);
int		EFISC	efisStopActive(int typescanner, unsigned char * addr, int port);

int		EFISC	efisStartupSensor(int handle);
int		EFISC	efisIsFingerPresent(int handle);
int 	EFISC	efisGetImage(int handle, unsigned char * img);
int		EFISC	efisGetHeight(int handle);
int		EFISC	efisGetWidth(int handle);
int		EFISC	efisGetType(int handle);

int		EFISC	efisInitConfiguration(int handle);

int		EFISC	efisIsFingerPresentV2(int handle);
int 	EFISC	efisGetImageV2(int handle, unsigned char * img);

int		EFISC	efisGetMsgErrors(int handle, unsigned char * msg);

int		EFISC	efisSetParam(int handle, unsigned char * param);
int		EFISC	efisGetParam(int handle, unsigned char * param);
int		EFISC	efisGetDeviceType(int handle);

int		EFISC	efisUpdateFirmware(int handle, unsigned char * bf);
int		EFISC	efisUpdateWEB(int handle, unsigned char * bf, int size);
int		EFISC	efisUpdateFirmwareM3(int handle, unsigned char * bf, unsigned long length);

int		EFISC	efisLedON(int handle, unsigned char flag);
int		EFISC	efisLedOFF(int handle, unsigned char flag);
int		EFISC	efisLedTimer(int handle, unsigned char flag, unsigned char sec);

int		EFISC	efisFlashOn(int handle, int	led, int frequency);
int		EFISC	efisFlashOff(int handle, int led);

void	EFISC	efisDisableYellowLED(void);
void	EFISC	efisEnableYellowLED(void);

int		EFISC	efisGetVersion(int handle, unsigned char * version);

void	EFISC	efisFlashLED(int handle, int type, int msec);

int		EFISC	efisRelay(int handle, int msec);
int		EFISC	efisRelayON(int handle);
int		EFISC	efisRelayOFF(int handle);
int		EFISC	efisRelayTimer(int handle);

int		EFISC	efisPingDevice(unsigned char * pstrHost);

int		EFISC	efisConvertToBmp24(int handle, unsigned char * Buf);
int		EFISC	efisConvertToBmp24V2(int handle, unsigned char * Buf);
int		EFISC	efisGetLengthBmp24(int handle);


int		EFISC	efisConvertToBmp8(int handle, unsigned char * Buf);
int		EFISC	efisGetLengthBmp8(int handle);


int		EFISC	efisSendToSerial(int handle, unsigned char * buf, unsigned char length);
int		EFISC	efisSendCommand(int handle, unsigned char command,  unsigned char num);
int		EFISC	efisGetList(int handle, unsigned char * list, int num);

int		EFISC	efisGetTemp(int handle, unsigned char * t);
int		EFISC	efisReboot(int handle);

unsigned char EFISC * efisGetSDKVersion(void);

int		EFISC efisTransmitImage(int typeScanner, int ServerSock, unsigned char * img);
int		EFISC efisGetImageFromClient(int typeScanner, int ServerSock);
int		EFISC efisCloseConnection(int typeScanner, int ServerSock);

int		EFISC efisFlashGreenLedON(int ServerSock);
int		EFISC efisFlashGreenLedOFF(int ServerSock);
int		EFISC efisClientLedON(int ServerSock, unsigned char flag);
int		EFISC efisClientLedOFF(int ServerSock, unsigned char flag);

int		EFISC efisClientSendToSerial(int ServerSock, unsigned char * buf, unsigned char length);

int		CommonInit(void);
int		CommonReset(void);
int		PingDevice(const char * addr);


//		IFIS functions
int		EFISC	efisGetRecognitionID(int handle, unsigned char * msg);

int		EFISC	efisWriteTemplateToIFIS(int handle,  unsigned char * buf, int size);
int		EFISC	efisReadTemplateFromIFIS(int handle,  unsigned char * buf, int size);
int		EFISC	efisDeleteTemplateInIFIS(int handle);


int		EFISC	efisReadTemplateFromMemoryIFIS(int handle,  unsigned char * buf, int size);

int		EFISC	efisLoadDataFromFlashInIFIS(int handle);
int		EFISC	efisSaveDataToFlashInIFIS(int handle);
int		EFISC	efisCreateUserInIFIS(int handle, unsigned char * user_ID, unsigned char * fname, unsigned char * lname);
int		EFISC	efisModifyUserInIFIS(int handle, unsigned char * user_ID, unsigned char * fname, unsigned char * lname);
int		EFISC	efisDeleteUserInIFIS(int handle, unsigned char user_ID);
int		EFISC	efisDeleteTemplatesOfUserInIFIS(int handle, unsigned char user_ID);
int		EFISC	efisCreateTemplateInIFIS(int handle, unsigned char user_ID);
int		EFISC	efisStopCreateTemplateInIFIS(int handle);

//	EFIS M3
int		EFISC	efis_DF_ReadStatusM3(int handle, unsigned char * val);
int		EFISC	efis_DF_SetPowerOf2M3(int handle, unsigned char * val);


//	EFIS for EFAC
int		EFISC	efisGetFPCode(int handle, char * fpc);


int	EFISC	erelRelayOn(int handle, unsigned char nRelay);
int	EFISC	erelRelayOff(int handle, unsigned char nRelay);
int	EFISC	erelAllRelayOff(int handle);
int EFISC	erelGetStatusRelay(int handle, unsigned char * version);
int EFISC	erelGetStatusInput(int handle, unsigned char * version);
int EFISC	erelGetAnswer(int handle, unsigned char * version);

int	EFISC	erelSendInputStatusOn(int handle);
int	EFISC	erelSendInputStatusOff(int handle);

//		EFIS configuration control functions

int	EFISC	efisReadConfiguration(int handle);
int	EFISC	efisWriteConfiguration(int handle);

int	EFISC	efisSetIPaddress(int handle, char * ipaddr);
int	EFISC	efisSetPort(int handle, short port);
int	EFISC	efisSetMask(int handle, char * mask);
int	EFISC	efisSetIPGetway(int handle, char * ipgw);
int	EFISC	efisSetIPServerAddress(int handle, char * ipaddr);
int	EFISC	efisSetPortServer(int handle, short port);


int	EFISC	efisGetIPaddress(int handle, char * ipaddr);
int	EFISC	efisGetPort(int handle, short * port);
int	EFISC	efisGetMask(int handle, char * mask);
int	EFISC	efisGetIPGetway(int handle, char * ipgw);
int	EFISC	efisGetIPServerAddress(int handle, char * ipaddr);
int	EFISC	efisGetPortServer(int handle, short * port);


#if defined (__cplusplus)          /* !defined (__cplusplus) */
}
#endif

#endif

